@@ -20,7 +20,7 @@ use Types::Standard qw/ Bool CodeRef HashRef Maybe Tuple /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.2.2';
+our $VERSION = 'v0.2.3';
 
 
 
@@ -74,7 +74,7 @@ sub _build_css_files {
     my ($self) = @_;
 
     my $root = $self->css_root;
-    my $min  = !$self->prefer_min;
+    my $min  = $self->prefer_min;
 
     my %files;
     for my $name (keys %{ $self->aliases }) {
@@ -84,12 +84,15 @@ sub _build_css_files {
         }
         else {
             $base = $name if $base eq '1';
-            my @bases = ( $base );
-            unshift @bases, "${base}.css" unless $base =~ /\.css$/;
-            unshift @bases, "${base}.min.css" unless $min || $base =~ /\.min\.css$/;
+            $base =~ s/(?:\.min)?\.css$//;
+            my @bases = $min
+                ? ( "${base}.min.css",  "${base}.css", $base )
+                : ( "${base}.css",  "${base}.min.css", $base );
+
             my $file = first { $_->exists } map { path( $root, $_ ) } @bases;
             unless ($file) {
-                croak "alias '$name' refers to a non-existent file";
+                $self->log->( error => "alias '$name' refers to a non-existent file" );
+                next;
             }
             # PATH NAME SIZE
             $files{$name} = [ $file, $file->relative($root)->stringify, $file->stat->size ];
@@ -169,11 +172,23 @@ has asset_id => (
 );
 
 
+has log => (
+    is => 'ro',
+    isa => CodeRef,
+    builder => sub {
+        return sub {
+            my ($level, $message) = @_;
+            croak $message if ($level eq 'error');
+            carp $message;
+        };
+    },
+);
+
+
+
 sub href {
     my ($self, $name, $file) = @_;
-    croak "missing name" unless defined $name;
-    $file //= $self->css_files->{$name};
-    croak "invalid name '$name'" unless defined $file;
+    $file //= $self->_get_file($name) or return;
     if (defined $file->[PATH]) {
         my $href = $self->url_base_path . $file->[NAME];
         $href .= '?' . $self->asset_id if $self->has_asset_id;
@@ -196,18 +211,17 @@ sub link_html {
 
 sub inline_html {
     my ( $self, $name, $file ) = @_;
-    croak "missing name" unless defined $name;
-    $file //= $self->css_files->{$name};
-    croak "invalid name '$name'" unless defined $file;
+    $file //= $self->_get_file($name) or return;
     if (my $path = $file->[PATH]) {
         if ($file->[SIZE]) {
             return "<style>" . $file->[PATH]->slurp_raw . "</style>";
         }
-        carp "empty file '$path'";
+        $self->log->( warning => "empty file '$path'" );
         return "";
     }
     else {
-        croak "'$name' refers to a URI";
+        $self->log->( error => "'$name' refers to a URI" );
+        return;
     }
 }
 
@@ -216,7 +230,7 @@ sub link_or_inline_html {
     my ($self, @names ) = @_;
     my $buffer = "";
     foreach my $name (uniqstr @names) {
-        my $file = $self->css_files->{$name} or croak "invalid name '$name'";
+        my $file = $self->_get_file($name) or next;
         if ( $file->[PATH] && ($file->[SIZE] <= $self->inline_max)) {
             $buffer .= $self->inline_html($name, $file);
         }
@@ -233,7 +247,7 @@ sub deferred_link_html {
     my $buffer = "";
     my @deferred;
     for my $name (uniqstr @names) {
-        my $file = $self->css_files->{$name} or croak "invalid name '$name'";
+        my $file = $self->_get_file($name) or next;
         if ($file->[PATH] && $file->[SIZE] <= $self->inline_max) {
             $buffer .= $self->inline_html($name, $file);
         }
@@ -262,6 +276,23 @@ sub deferred_link_html {
     return $buffer;
 }
 
+sub _get_file {
+    my ($self, $name) = @_;
+    unless (defined $name) {
+        $self->log->( error => "missing name" );
+        return;
+    }
+    if (my $file = $self->css_files->{$name}) {
+        return $file;
+    }
+    else {
+        $self->log->( error => "invalid name '$name'" );
+        return;
+    }
+
+}
+
+
 
 1;
 
@@ -277,7 +308,7 @@ HTML::DeferableCSS - Simplify management of stylesheets in your HTML
 
 =head1 VERSION
 
-version v0.2.2
+version v0.2.3
 
 =head1 SYNOPSIS
 
@@ -486,6 +517,27 @@ of files.
 
 True if there is an L</asset_id>.
 
+=head2 log
+
+This is a code reference for logging errors and warnings:
+
+  $css->log->( $level => $message );
+
+By default, this is a wrapper around L<Carp> that dies when the level
+is "error", and emits a warning for everything else.
+
+You can override this so that errors are treated as warnings,
+
+  log => sub { warn $_[1] },
+
+or that warnings are fatal,
+
+  log => sub { die $_[1] },
+
+or even integrate this with your own logging system:
+
+  log => sub { $logger->log(@_) },
+
 =head1 METHODS
 
 =head2 href
